@@ -24,8 +24,8 @@
  * ᡼󥰥ꥹȰ
  *
  * $RCSfile: admin_ml_list.php,v $
- * $Revision: 1.19 $
- * $Date: 2008/12/02 00:54:42 $
+ * $Revision: 1.22 $
+ * $Date: 2009/06/12 06:00:29 $
  **********************************************************/
 
 include_once("../../lib/libcommon");
@@ -66,6 +66,7 @@ Class my_page extends page {
             $newml = htmlspecialchars($_POST["newml"]);
         }
 
+        $domain = htmlspecialchars($domain);
         print <<<EOD
 
 <script type="text/javascript">
@@ -287,6 +288,7 @@ if (isset($_POST["add"])) {
             result_log(OPERATION . ":NG:" . $err_msg);
         } else {
             result_log(OPERATION . ":OK:" . $err_msg);
+            $err_msg = htmlspecialchars($err_msg);
         }
     } else {
         $err_msg = "᡼󥰥ꥹȥɥ쥹򤵤Ƥޤ";
