@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: admin_user_mod.php,v $
- * $Revision: 1.31 $
- * $Date: 2008/11/20 00:01:19 $
+ * $Revision: 1.35 $
+ * $Date: 2009/06/19 00:36:01 $
  **********************************************************/
 
 include_once("../../lib/libcommon");
@@ -66,21 +66,25 @@ Class my_page extends page {
         global $sesskey;
         global $user;
         global $dispusr;
-        global $mail;
         global $mode;
         global $ldapdata;
         global $userdn;
 
+        /* DNΰŹ沽 */
         $userdn = base64_encode($userdn);
         $userdn = str_rot13($userdn);
 
+        /* 桼̾ΰŹ沽 */
+        $form_name = base64_encode($_POST["name"]);
+        $form_name = str_rot13($form_name);
+
         /* hiddenϤǡǼ */
         $hiddendata['dn'] = $userdn;
-        $hiddendata['uid'] = $user;
-        $hiddendata['mail'] = $mail;
         $hiddendata['sk'] = $sesskey;
         $hiddendata['page'] = $_POST["page"];
         $hiddendata['filter'] = $_POST["filter"];
+        $hiddendata['form_name'] = $form_name;
+        $hiddendata['name_match'] = $_POST['name_match'];
 
         if ($mode == MOD_MODE) {
 
@@ -174,6 +178,39 @@ $err_msg = "";
  * main
  **********************************************************/
 /* ʬ */
+/* ڡηå */
+if (is_num_check($page) === FALSE) {
+    $err_msg = "ڡͤǤ";
+    $sys_err = TRUE;
+    $pg->display(null, null);
+    exit (1);
+}
+
+/* ե륿ʣ粽 */
+if (sess_key_decode($filter, $dec_filter) === FALSE) {
+    $sys_err = TRUE;
+    $pg->display(null, null);
+    exit (1);
+}
+
+/* ե륿ηå */
+$fdata = explode(':', $dec_filter);
+if (count($fdata) != 3) {
+    $err_msg = "ե륿ηǤ";
+    $sys_err = TRUE;
+    $pg->display(null, null);
+    exit (1);
+}
+
+/* DNηå */
+$len = (-1) * strlen($web_conf['ldapbasedn']);
+$cmpdn = substr($userdn, $len);
+if (strcmp($cmpdn, $web_conf['ldapbasedn']) != 0) {
+    $err_msg = "DNηǤ";
+    $sys_err = TRUE;
+    $pg->display(null, null);
+    exit (1);
+}
 
 /* 桼μ */
 $ret = get_userdata($userdn);
@@ -192,17 +229,23 @@ $user = $ldapdata[0]["uid"][0];
 $dispattr = $web_conf['displayuser'];
 $dispusr = $ldapdata[0][$dispattr][0];
 
-/* ᡼륢ɥ쥹Ǽ */
-$mail = $ldapdata[0]["mail"][0];
+/* եǼ */
+$form_name = $_POST["form_name"];
+$name_match = $_POST["name_match"];
 
 if (isset($_POST['modify'])) {
 
     /* ⡼ */
     $mode = POST_MOD_MODE;
 
+    /* ѹѥǡ */
+    $data = $_POST;
+    $data["mail"] = $ldapdata[0]["mail"][0];
+    $data["uid"] = $ldapdata[0]["uid"][0];
+
     /* ϥǡΥå */
-    if (check_mod_data($_POST) === FALSE ||
-        mod_user($_POST) === FALSE) {
+    if (check_mod_data($data) === FALSE ||
+        mod_user($data) === FALSE) {
         result_log(OPERATION . ":NG:" . $err_msg);
     } else {
         $err_msg = "桼򹹿ޤ(" . $dispusr . ")";
