@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: admin_user_search.php,v $
- * $Revision: 1.16 $
- * $Date: 2008/11/28 02:40:43 $
+ * $Revision: 1.21 $
+ * $Date: 2009/06/22 05:29:31 $
  **********************************************************/
 
 include_once("../../lib/libcommon");
@@ -80,9 +80,10 @@ function print_form()
     global $web_conf;
     global $status;
     global $sesskey;
+    global $form_name;
 
-    if (isset($_POST['name'])) {
-        $name = htmlspecialchars($_POST['name']);
+    if (isset($form_name)) {
+        $name = htmlspecialchars($form_name);
 
         /* ޥå */
         if ($_POST["name_match"] == 0) {
@@ -160,6 +161,11 @@ function print_title($sum, $filter)
         $all_page = 1;
     }
 
+    /* ڡʾοϤäƤǸΥڡɽ */
+    if ($all_page < $page + 1) {
+        $page = $all_page - 1;
+    }
+
     /* ɽƤǸΰ硢Υڡɽ */
     $ret = $sum % $all_page;
     if ($ret == 0 && $all_page < $page + 1) {
@@ -180,8 +186,6 @@ function print_title($sum, $filter)
         $next = "<a href=\"#\" onClick=\"allSubmit('admin_user_search.php', '$tmp', '')\">ڡ</a>";
     }
 
-    $filter_disp = base64_encode($filter);
-    $filter_disp = str_rot13($filter_disp);
     print <<<EOD
 
 <script type="text/javascript">
@@ -200,7 +204,6 @@ function allSubmit(url, page, dn) {
 <input type="hidden" name="filter" value="{$filter_disp}">
 <input type="hidden" name="page" value="{$page}">
 <input type="hidden" name="sk" value="{$sesskey}">
-<input type="hidden" name="sum" value="{$sum}">
 <input type="hidden" name="dn">
 <table class="table">
     <tr>
@@ -457,6 +460,11 @@ if (isset($_POST["sk"])) {
     $sesskey = $_POST["sk"];
 }
 
+/* եϤ줿 */
+if (isset($_POST['name'])) {
+    $form_name = $_POST['name'];
+}
+
 /* ɥᥤ */
 $domain = $_SERVER['DOMAIN'];
 
@@ -501,7 +509,6 @@ if (isset($_POST["msg"])) {
 /***********************************************************
  * main
  **********************************************************/
-
 $logstr = OPERATION;
 
 /* ɽ° */
@@ -517,11 +524,40 @@ if ($status == STATUS_SEARCH) {
         result_log($logstr);
     } else {
         /* Υե륿 */
-        if ((!isset($_POST["search"]) || !isset($_POST["csvdownload"])) &&
+        if ((!isset($_POST["search"]) && !isset($_POST["csvdownload"])) &&
              $_POST["filter"] != "") {
-            $filter = str_rot13($_POST["filter"]);
-            $filter = base64_decode($filter);
+            /* եϤ줿ͤʣ粽 */
+            if (isset($_POST['form_name'])) {
+                $form_name = str_rot13($_POST['form_name']);
+                $form_name = base64_decode($form_name);
+            }
+
+            /* ڡͥå */
+            if (is_num_check($_POST["page"]) === FALSE) {
+                $err_msg = "ڡͤǤ";
+                $sys_err = TRUE;
+                $pg->display(null, null);
+                exit (1);
+            }
             $page = $_POST["page"];
+
+            /* ե륿ʣ粽 */
+            if (sess_key_decode($_POST["filter"], $filter) === FALSE) {
+                $sys_err = TRUE;
+                $pg->display(null, null);
+                exit (1);
+            }
+
+            /* ե륿ηå */
+            $fdata = explode(':', $filter);
+            if (count($fdata) != 3) {
+                $err_msg = "ե륿ηǤ";
+                $sys_err = TRUE;
+                $pg->display(null, null);
+                exit (1);
+            }
+            $filter = $fdata[1];
+
         } else {
             /* ե륿 */
             $filter = mk_filter($_POST["name"], $_POST["name_match"]);
@@ -544,9 +580,16 @@ if ($status == STATUS_SEARCH) {
             result_log($logstr);
         }
 
+        /* ե륿ΰŹ沽 */
+        if (sess_key_make($filter, "", $filter_disp) === FALSE) {
+            $sys_err = TRUE;
+            $pg->display(null, null);
+            exit (1);
+        }
+
         /* ¾Υڡۤåɽ */
         if (isset($_POST["msg"])) {
-            $err_msg = $_POST["msg"];
+            $err_msg = htmlspecialchars($_POST["msg"]);
         }
     }
 } 
